==> qmmp-0.12.20.tar.bz2: qmmp-0.12.20/src/plugins/General/lyrics/translations/lyrics_plugin_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="el">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="33"/>
        <source>View Lyrics</source>
        <translation>Προβολή στίχων</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="34"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="30"/>
        <source>Lyrics Plugin</source>
        <translation>Πρόσθετο στίχων</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="50"/>
        <source>About Lyrics Plugin</source>
        <translation>Σχετικά με το πρόσθετο στίχων</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>Qmmp πρόσθετο στίχων</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>This plugin retrieves lyrics from LyricWiki</source>
        <translation>Αυτό το πρόσθετο κάνει λήψη στίχων από το LyricWiki</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Γράφτηκε από τον: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="54"/>
        <source>Based on Ultimate Lyrics script by Vladimir Brkic &lt;vladimir_brkic@yahoo.com&gt;</source>
        <translation>Βασισμένο στην μακροεντολή Ultimate Lyrics του Vladimir Brkic &lt;vladimir_brkic@yahoo.com&gt;</translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>Πρόσθετο στίχων</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="31"/>
        <source>Provider:</source>
        <translation>Πάροχος</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="122"/>
        <source>Album:</source>
        <translation>Δίσκος:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="139"/>
        <source>Track:</source>
        <translation>Κομμάτι:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="146"/>
        <source>Artist:</source>
        <translation>Καλλιτέχνης:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="161"/>
        <source>Year:</source>
        <translation>Έτος:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="115"/>
        <source>Title:</source>
        <translation>Τίτλος:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="113"/>
        <source>&lt;h2&gt;%1 - %2&lt;/h2&gt;</source>
        <translation>&lt;h2&gt;%1 - %2&lt;/h2&gt;</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="124"/>
        <source>Not found</source>
        <translation>Δεν βρέθηκε</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="134"/>
        <source>Error: %1 - %2</source>
        <translation>Σφάλμα: %1 - %2</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="147"/>
        <source>Receiving</source>
        <translation>Γίνεται λήψη</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="202"/>
        <source>cache</source>
        <translation>κρυφή μνήμη</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Lyrics Plugin Settings</source>
        <translation>Ρυθμίσεις πρόσθετου στίχων</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Lyrics providers:</source>
        <translation>Πάροχοι στίχων</translation>
    </message>
</context>
<context>
    <name>UltimateLyricsParser</name>
    <message>
        <location filename="../ultimatelyricsparser.cpp" line="118"/>
        <source>%1 (line: %2)</source>
        <translation>%1 (γραμμή: %2)</translation>
    </message>
</context>
</TS>

==> qmmp_1.1.10.orig.tar.bz2: qmmp-1.1.10/src/plugins/General/lyrics/translations/lyrics_plugin_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="el">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="33"/>
        <source>View Lyrics</source>
        <translation>Προβολή στίχων</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="34"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="29"/>
        <source>Lyrics Plugin</source>
        <translation>Πρόσθετο στίχων</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="50"/>
        <source>About Lyrics Plugin</source>
        <translation>Σχετικά με το πρόσθετο στίχων</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>Qmmp πρόσθετο στίχων</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>This plugin retrieves lyrics from LyricWiki</source>
        <translation>Αυτό το πρόσθετο κάνει λήψη στίχων από το LyricWiki</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Γράφτηκε από τον: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>Πρόσθετο στίχων</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="31"/>
        <source>Artist:</source>
        <translation>Καλλιτέχνης:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="41"/>
        <source>Title:</source>
        <translation>Τίτλος:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="51"/>
        <source>Search</source>
        <translation>Αναζήτηση</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="60"/>
        <source>No connection</source>
        <translation>Χωρίς σύνδεση</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="64"/>
        <source>Done</source>
        <translation>Έγινε</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="67"/>
        <location filename="../lyricswindow.cpp" line="91"/>
        <location filename="../lyricswindow.cpp" line="97"/>
        <location filename="../lyricswindow.cpp" line="105"/>
        <location filename="../lyricswindow.cpp" line="113"/>
        <location filename="../lyricswindow.cpp" line="124"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="118"/>
        <location filename="../lyricswindow.cpp" line="153"/>
        <source>Not found</source>
        <translation>Δεν βρέθηκε</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="139"/>
        <location filename="../lyricswindow.cpp" line="164"/>
        <source>Receiving</source>
        <translation>Γίνεται λήψη</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="165"/>
        <source>Lyrics: %1 - %2</source>
        <translation>Στίχοι: %1 - %2</translation>
    </message>
</context>
</TS>
